<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling">
<xsl:output encoding="UTF-8" method="xml"/>
<xsl:param name="pParam"/>

<xsl:template match="/*">
<xsl:copy><xsl:apply-templates select="@*|node()"/></xsl:copy>
</xsl:template>
	
<xsl:template match="sm:imageTransform">
<xsl:element name="{si(parent::sm:binary,'sm:imageSize','sm:imageTransform')}">
<xsl:if test="@scale != ''"><sm:scale ratio="{@scale}"/></xsl:if>
<xsl:if test="@minWidth != '' or @maxWidth != '' or @minHeight != '' or @maxHeight != ''">
<sm:sizeBounds>
<xsl:if test="@minWidth != ''"><xsl:attribute name="minWidthInPx"><xsl:value-of select="@minWidth"/></xsl:attribute></xsl:if>
<xsl:if test="@maxWidth != ''"><xsl:attribute name="maxWidthInPx"><xsl:value-of select="@maxWidth"/></xsl:attribute></xsl:if>
<xsl:if test="@minHeight != ''"><xsl:attribute name="minHeightInPx"><xsl:value-of select="@minHeight"/></xsl:attribute></xsl:if>
<xsl:if test="@maxHeight != ''"><xsl:attribute name="maxHeightInPx"><xsl:value-of select="@maxHeight"/></xsl:attribute></xsl:if>
</sm:sizeBounds>
</xsl:if>
<xsl:choose>
<xsl:when test="parent::sm:binary"/>
<xsl:when test="@outputType != ''"><xsl:element name="sm:output{@outputType}"/></xsl:when>
<xsl:otherwise><sm:outputPNG/></xsl:otherwise>
</xsl:choose>
</xsl:element>
</xsl:template>
	
<xsl:template match="sm:freeTransform[@code='odf2gif' or @code='odf2jpg' or @code='odf2png' or @code='odf2swf' or @code='odg2gif' or @code='odg2jpg' or @code='odg2png' or @code='odg2swf' or @code='ods2gif' or @code='ods2jpg' or @code='ods2png' or @code='ods2swf']">
<xsl:variable name="vOutputType" select="si(@code,translate(substring-after(@code,'2'),'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ'),'')"/>
<xsl:variable name="vOpts" select="si(@options,concat(translate(@options,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz'),'&amp;'),'')"/>
<xsl:variable name="vScale" select="si(contains($vOpts,'scale='),substring-before(substring-after($vOpts,'scale='),'&amp;'),'')"/>
<xsl:variable name="vMinWidth" select="si(contains($vOpts,'minwidth='),substring-before(substring-after($vOpts,'minwidth='),'px&amp;'),'')"/>
<xsl:variable name="vMaxWidth" select="si(contains($vOpts,'maxwidth='),substring-before(substring-after($vOpts,'maxwidth='),'px&amp;'),'')"/>
<xsl:variable name="vMinHeight" select="si(contains($vOpts,'minheight='),substring-before(substring-after($vOpts,'minheight='),'px&amp;'),'')"/>
<xsl:variable name="vMaxHeight" select="si(contains($vOpts,'maxheight='),substring-before(substring-after($vOpts,'maxheight='),'px&amp;'),'')"/>
<xsl:variable name="vBackgroundColor" select="si(contains($vOpts,'backgroundcolor=#'),substring-before(substring-after($vOpts,'backgroundcolor=#'),'&amp;'),'')"/>
		
<xsl:element name="{si(parent::sm:binary,'sm:odSize','sm:odTransform')}">
<xsl:if test="$vBackgroundColor != ''"><xsl:attribute name="bgColor"><xsl:value-of select="$vBackgroundColor"/></xsl:attribute></xsl:if>
<xsl:if test="$vScale != ''"><sm:scale ratio="{$vScale}"/></xsl:if>
<xsl:if test="$vMinWidth != '' or $vMaxWidth != '' or $vMinHeight != '' or vMaxHeight != ''">
<sm:sizeBounds>
<xsl:if test="$vMinWidth != ''"><xsl:attribute name="minWidthInPx"><xsl:value-of select="$vMinWidth"/></xsl:attribute></xsl:if>
<xsl:if test="$vMaxWidth != ''"><xsl:attribute name="maxWidthInPx"><xsl:value-of select="$vMaxWidth"/></xsl:attribute></xsl:if>
<xsl:if test="$vMinHeight != ''"><xsl:attribute name="minHeightInPx"><xsl:value-of select="$vMinHeight"/></xsl:attribute></xsl:if>
<xsl:if test="$vMaxHeight != ''"><xsl:attribute name="maxHeightInPx"><xsl:value-of select="$vMaxHeight"/></xsl:attribute></xsl:if>
</sm:sizeBounds>
</xsl:if>
<xsl:choose>
<xsl:when test="parent::sm:binary"/>
<xsl:when test="$vOutputType != ''"><xsl:element name="sm:output{si($vOutputType = 'JPG','JPEG',$vOutputType)}"/></xsl:when>
<xsl:otherwise><sm:outputPNG/></xsl:otherwise>
</xsl:choose>
</xsl:element>
</xsl:template>

<xsl:template match="sm:size">
<sm:declareSize><xsl:apply-templates select="@*"/></sm:declareSize>
</xsl:template>
	
<xsl:template match="sm:when">
<sm:whenSize><xsl:apply-templates select="@*|node()"/></sm:whenSize>
</xsl:template>
	
<xsl:template match="sm:binary[@outputType='flash' and not(sm:freeTransform/@code='odf2swf' or sm:freeTransform/@code='odg2swf' or sm:freeTransform/@code='ods2swf')]">
<xsl:copy><xsl:apply-templates select="@*|node()"/><sm:swfSize/></xsl:copy>
</xsl:template>

<xsl:template match="sm:binary[@outputType='image' and not(sm:imageTransform or sm:freeTransform)]">
<xsl:copy><xsl:apply-templates select="@*|node()"/><sm:imageSize/></xsl:copy>
</xsl:template>

<xsl:template match="sm:binary/@outputType"/>

<xsl:template match="sm:WAudio|sm:WObject|sm:WVideo">
<xsl:copy>
<xsl:apply-templates select="@*"/>
<xsl:apply-templates select="sm:binaryUrl"/>
<xsl:apply-templates select="sm:pluginType "/>
<xsl:if test="sm:width or sm:height">
<sm:declareSize>
<xsl:if test="sm:width"><xsl:attribute name="width"><xsl:value-of select="sm:width/sm:fixedValue/@value"/></xsl:attribute></xsl:if>
<xsl:if test="sm:height"><xsl:attribute name="height"><xsl:value-of select="sm:height/sm:fixedValue/@value"/></xsl:attribute></xsl:if>
</sm:declareSize>
</xsl:if>
<xsl:apply-templates select="sm:showControls"/>
<xsl:apply-templates select="sm:autoStart"/>
<xsl:apply-templates select="sm:loop"/>
<xsl:apply-templates select="sm:classid"/>
<xsl:apply-templates select="sm:codebase"/>
<xsl:apply-templates select="sm:pluginspage"/>
<xsl:apply-templates select="sm:param"/>
</xsl:copy>
</xsl:template>
	
		
	
	
	
<xsl:template match="@*|node()">
<xsl:copy>
<xsl:apply-templates select="@*|node()"/>
</xsl:copy>
</xsl:template>
		
</xsl:stylesheet>