<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sng="http://relaxng.org/ns/structure/1.0"
		xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
		xmlns:xalan="http://xml.apache.org/xalan"
		exclude-result-prefixes="sc sp sm sng snga xalan"
		version="1.0">
<xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>
	
<xsl:include href="bsco:sm/model/relaxNg.xsl"/>
	
<xsl:template match="sm:compositionPrim">
<xsl:value-of select="execute(setEntryBuffer('ns', string(sm:identification/@targetPrefix), string(sm:identification/@targetNamespace)))"/>
<xsl:value-of select="execute(setEntryBuffer('ns', 'sp', 'http://www.utc.fr/ics/scenari/v3/primitive'))"/>
<sng:define name="{sm:identification/@targetPrefix}_{sm:identification/@code}">
<sng:element name="{sm:identification/@targetPrefix}:{sm:identification/@code}" snga:title="{si(@info, concat(filterInlineLoc(@name), ' (',@info, ')'), filterInlineLoc(@name))}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:apply-templates select="sm:structure"/>
</sng:element>
</sng:define>
</xsl:template>
<xsl:template match="sm:structure">
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:apply-templates/>
<xsl:if test="count(*)=0">
			
<sng:empty/>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:part[@usage='optional']">
<xsl:variable name="vIsNotEmpty"><xsl:call-template name="isPartNotEmpty"/></xsl:variable>
<xsl:if test="$vIsNotEmpty != ''">
<sng:optional>
<xsl:call-template name="part"/>
</sng:optional>	
</xsl:if>
</xsl:template>
<xsl:template match="sm:part">
<xsl:variable name="vIsNotEmpty"><xsl:call-template name="isPartNotEmpty"/></xsl:variable>
<xsl:if test="$vIsNotEmpty != ''">
<xsl:call-template name="part"/>
</xsl:if>
</xsl:template>
<xsl:template name="isPartNotEmpty">
<xsl:choose>
<xsl:when test="not(sm:allowedModel)">
				
<xsl:if test="si(sm:meta, resultatAgent(concat('@', getIdFromPath(sm:meta/@sc:refUri), '/isInternalizable')) = 'true') or si(sm:metaIfExternalized, resultatAgent(concat('@', getIdFromPath(sm:metaIfExternalized/@sc:refUri), '/isInternalizable')) = 'true')">1</xsl:if>
</xsl:when>
<xsl:otherwise>
				
<xsl:variable name="vIsInternalizable" select="si(@internalized = 'never', false(), testExpr(sm:allowedModel[not(@restrictUserDep='neverInternalized')], resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true', 'or'))"/>
<xsl:variable name="vIsExternalizable" select="si(@internalized = 'always', false(), testExpr(sm:allowedModel[not(@restrictUserDep='neverExternalized')], resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isStandAloneItem')) = 'true', 'or'))"/>
<xsl:if test="$vIsInternalizable or $vIsExternalizable">1</xsl:if>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<xsl:template name="part">
<xsl:variable name="vHasAllowedModel" select="si(boolean(sm:allowedModel), true(), false())"/>
<sng:element name="sp:{@code}" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<xsl:choose>
<xsl:when test="@internalized = 'userDependent' and boolean(sm:metaIfExternalized)">
<sng:choice>
<sng:group>
<xsl:apply-templates select="sm:metaIfExternalized" mode="title"/>
<xsl:call-template name="partProperties"/>
<xsl:if test="$vHasAllowedModel">
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
</xsl:if>
<sng:empty/>
</sng:group>
<sng:group>
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:call-template name="partProperties"/>
<xsl:call-template name="innerPart"/>
</sng:group>
</sng:choice>
</xsl:when>
<xsl:when test="@internalized = 'userDependent'">
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:call-template name="partProperties"/>
<xsl:choose>
<xsl:when test="$vHasAllowedModel">
<sng:choice>
<sng:group>
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
<sng:empty/>
</sng:group>	
<xsl:call-template name="innerPart"/>
</sng:choice>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:when test="@internalized = 'always'">
<xsl:apply-templates select="sm:meta" mode="title"/>
<xsl:call-template name="partProperties"/>
<xsl:call-template name="innerPart"/>
</xsl:when>
<xsl:otherwise>
					
<xsl:if test="$vHasAllowedModel">
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
</xsl:if>
<xsl:choose>
<xsl:when test="sm:metaIfExternalized">
<xsl:apply-templates select="sm:metaIfExternalized" mode="title"/>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="sm:meta" mode="title"/>
</xsl:otherwise>
</xsl:choose>
<xsl:call-template name="partProperties"/>
<sng:empty/>
</xsl:otherwise>			
</xsl:choose>
</sng:element>
</xsl:template>
<xsl:template name="innerPart">
<xsl:variable name="vModels">
<xsl:apply-templates/>
</xsl:variable>
<xsl:variable name="vCount" select="count(xalan:nodeset($vModels)/*)"/>
<xsl:choose>
<xsl:when test="$vCount &gt; 1">
<sng:choice>
<xsl:copy-of select="$vModels"/>
</sng:choice>
</xsl:when>
<xsl:when test="$vCount = 1">
<xsl:copy-of select="$vModels"/>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
	
	
<xsl:template match="sm:set">
<xsl:variable name="vModels"><xsl:apply-templates/></xsl:variable>
<xsl:variable name="vCount" select="count(xalan:nodeset($vModels)/*)"/>
<xsl:variable name="vCard" select="si(@usage='optional', 'sng:zeroOrMore', 'sng:oneOrMore')"/>
<xsl:choose>
<xsl:when test="$vCount &gt; 1">
<xsl:element name="{$vCard}">
<sng:choice>
<xsl:copy-of select="$vModels"/>
</sng:choice>
</xsl:element>
</xsl:when>
<xsl:when test="$vCount = 1">
<xsl:element name="{$vCard}">
<xsl:copy-of select="$vModels"/>
</xsl:element>
</xsl:when>
<xsl:otherwise>
<sng:empty/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:alternative[@usage='optional']">
<sng:optional>
<sng:choice>
<xsl:apply-templates/>
</sng:choice>
</sng:optional>
</xsl:template>
<xsl:template match="sm:alternative">
<sng:choice>
<xsl:apply-templates/>
</sng:choice>
</xsl:template>
	
<xsl:template match="sm:meta[@usage='optional']|sm:metaIfExternalized[@usage='optional']" mode="title">
<xsl:if test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:optional>
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</sng:optional>
</xsl:if>
</xsl:template>
<xsl:template match="sm:meta|sm:metaIfExternalized" mode="title">
<xsl:if test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:allowedModel">
<xsl:if test="not(@restrictUserDep='neverInternalized') and resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:if>
</xsl:template>
	
<xsl:template match="*"/>
<xsl:template match="text()|@*"/>
</xsl:stylesheet>