<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sng="http://relaxng.org/ns/structure/1.0" 
		xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling" 
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:xalan="http://xml.apache.org/xalan"
		exclude-result-prefixes="sc sm sng snga xalan"
		version="1.0">
<xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>
	
<xsl:include href="bsco:sm/model/relaxNg.xsl"/>

<xsl:template match="sm:textPrim">
<xsl:value-of select="execute(setEntryBuffer('ns', resultatAgent('//prefixModel'), resultatAgent('//nsModel')))"/>
<sng:define name="{resultatAgent('//codeModel')}">
<sng:element name="{resultatAgent('//qNameTagRootModel')}" snga:title="{si(@info, concat(filterInlineLoc(@name), ' (',@info, ')'), filterInlineLoc(@name))}">
<xsl:call-template name="tGetRngDocumentationTag">
<xsl:with-param name="pDocTxt" select="returnFirst(sm:doc, filterInlineLoc(sm:help/@quickHelp))"/>
</xsl:call-template>
<sng:ref name="{resultatAgent('//codeModel')}_blocs"/>
</sng:element>
</sng:define>
<sng:define name="{resultatAgent('//codeModel')}_blocs">
<xsl:choose>
<xsl:when test="boolean(sm:structure/sm:blockTags/*)">
<sng:oneOrMore>
<sng:choice>
<xsl:apply-templates select="sm:structure/sm:blockTags"/>
</sng:choice>
</sng:oneOrMore>
</xsl:when>
<xsl:otherwise>
<sng:element name="sc:para">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</xsl:otherwise>
</xsl:choose>
</sng:define>
<sng:define name="{resultatAgent('//codeModel')}_inline">
<sng:zeroOrMore>
<sng:choice>
<sng:text/>
<xsl:apply-templates select="sm:structure/sm:inlineTags"/>
</sng:choice>
</sng:zeroOrMore>
</sng:define>
<sng:define name="{resultatAgent('//codeModel')}_id">
<sng:optional>
<sng:attribute name="sc:id">
<sng:data type="ID"/>
</sng:attribute>
</sng:optional>
</sng:define>
<xsl:apply-templates select="sm:structure/*" mode="define"/>
</xsl:template>
	
	
<xsl:template match="sm:blockTags">
<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="sm:paraTag">
<sng:element name="sc:para" snga:title="{filterInlineLoc(@name)}">
			
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
<xsl:apply-templates select="sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:simpleListTag">
<sng:element name="sc:simpleList" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<xsl:if test="sm:titleTag">
<sng:optional>
<sng:element name="sc:title" snga:title="{filterInlineLoc(sc:title/@name)}">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</sng:optional>
</xsl:if>
<sng:zeroOrMore>
<sng:element name="sc:member">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
<xsl:apply-templates select="sm:memberTag/sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
</sng:element>
</sng:zeroOrMore>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:itemizedListTag">
<sng:element name="sc:itemizedList" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<xsl:if test="sm:titleTag">
<sng:optional>
<sng:element name="sc:title" snga:title="{filterInlineLoc(sc:title/@name)}">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</sng:optional>
</xsl:if>
<sng:zeroOrMore>
<sng:element name="sc:listItem">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:listItemTag/sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_blocs"/>
</sng:element>
</sng:zeroOrMore>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:orderedListTag">
<sng:element name="sc:orderedList" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<xsl:if test="sm:titleTag">
<sng:optional>
<sng:element name="sc:title" snga:title="{filterInlineLoc(sc:title/@name)}">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</sng:optional>
</xsl:if>
<sng:zeroOrMore>
<sng:element name="sc:listItem">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:listItemTag/sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_blocs"/>
</sng:element>
</sng:zeroOrMore>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:tableTag">
<sng:element name="sc:table" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<xsl:if test="sm:captionTag">
<sng:optional>
<sng:element name="sc:caption" snga:title="{filterInlineLoc(sc:caption/@name)}">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</sng:optional>
</xsl:if>
<sng:zeroOrMore>
<xsl:choose>
<xsl:when test="count(sm:columnTag)&gt;1">
<sng:choice>
<xsl:apply-templates select="sm:columnTag"/>
</sng:choice>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="sm:columnTag"/>
</xsl:otherwise>
</xsl:choose>
</sng:zeroOrMore>
<sng:zeroOrMore>
<xsl:choose>
<xsl:when test="count(sm:rowTag)&gt;1">
<sng:choice>
<xsl:apply-templates select="sm:rowTag"/>
</sng:choice>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="sm:rowTag"/>
</xsl:otherwise>
</xsl:choose>
</sng:zeroOrMore>
<sng:ref name="{resultatAgent('//codeModel')}_cells_{@role}"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:columnTag">
<sng:element name="sc:column" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:attribute name="width">
<sng:data type="string"/>
</sng:attribute>
			
</sng:element>
</xsl:template>
	
<xsl:template match="sm:rowTag">
<sng:element name="sc:row" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_cells_{../@role}"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:extBlockTag">
<sng:element name="sc:extBlock" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
<xsl:apply-templates select="sm:meta"/>
<xsl:if test="sm:captionBlockTag">
<sng:optional>
<sng:element name="sc:captionBlock" snga:title="{filterInlineLoc(sc:captionBlock/@name)}">
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
<sng:optional>
<sng:attribute name="xml:space">
<sng:value>preserve</sng:value>
</sng:attribute>
</sng:optional>
</sng:element>
</sng:optional>
</xsl:if>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:emptyBlockTag">
<sng:element name="sc:emptyBlock" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
</sng:element>
</xsl:template>
	
	
	
	
	
<xsl:template match="sm:inlineTags">
<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="sm:uLinkTag">
<sng:element name="sc:uLink" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:optional>
<sng:attribute name="url">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
</sng:optional>
<sng:optional>
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
</sng:optional>
<xsl:apply-templates select="sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:phraseTag">
<sng:element name="sc:phrase" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:optional>
				
<sng:attribute name="xml:lang">
<sng:data type="string"/>
</sng:attribute>
</sng:optional>
<xsl:apply-templates select="sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:inlineStyleTag">
<sng:element name="sc:inlineStyle" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<sng:ref name="{resultatAgent('//codeModel')}_inline"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:textLeafTag">
<sng:element name="sc:textLeaf" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
<sng:text/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:objectLeafTag">
<sng:element name="sc:objectLeaf" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
<xsl:apply-templates select="sm:meta"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:emptyLeafTag">
<sng:element name="sc:emptyLeaf" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<xsl:apply-templates select="sm:meta"/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:inlineImgTag">
<sng:element name="sc:inlineImg" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:attribute name="sc:refUri">
<sng:data type="string">
<sng:param name="minLength">1</sng:param>
</sng:data>
</sng:attribute>
<xsl:apply-templates select="sm:meta"/>
<sng:text/>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:noteTag">
<sng:element name="sc:note" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:ref name="{resultatAgent('//codeModel')}"/>
</sng:element>
</xsl:template>
	
	
	
<xsl:template match="sm:blockTags" mode="define">
<xsl:apply-templates mode="define"/>
</xsl:template>
<xsl:template match="sm:tableTag" mode="define">
<sng:define name="{resultatAgent('//codeModel')}_cells_{@role}">
<sng:zeroOrMore>
<xsl:choose>
<xsl:when test="count(sm:cellTag)&gt;1">
<sng:choice>
<xsl:apply-templates select="sm:cellTag" mode="define"/>
</sng:choice>
</xsl:when>
<xsl:otherwise>
<xsl:apply-templates select="sm:cellTag" mode="define"/>
</xsl:otherwise>
</xsl:choose>
</sng:zeroOrMore>
</sng:define>
</xsl:template>
<xsl:template match="sm:cellTag" mode="define">
<sng:element name="sc:cell" snga:title="{filterInlineLoc(@name)}">
<xsl:call-template name="attRole"/>
<sng:ref name="{resultatAgent('//codeModel')}_id"/>
<sng:optional>
<sng:attribute name="rowSpan">
<sng:data type="string"/>
</sng:attribute>
</sng:optional>
<sng:optional>
<sng:attribute name="colSpan">
<sng:data type="string"/>
</sng:attribute>
</sng:optional>
<xsl:apply-templates select="sm:meta"/>
<sng:optional>
<sng:ref name="{resultatAgent('//codeModel')}_blocs"/>
</sng:optional>
</sng:element>
</xsl:template>
	
<xsl:template match="sm:inlineTags" mode="define">
<xsl:apply-templates mode="define"/>
</xsl:template>
	
<xsl:template match="node()" mode="define"/>
	
	
<xsl:template name="attRole">
<xsl:choose>
<xsl:when test="string(@role)">
				
<sng:attribute name="role">
<sng:value>
<xsl:value-of select="@role"/>
</sng:value>
</sng:attribute>
</xsl:when>
<xsl:otherwise>
				
<sng:optional>
<sng:attribute name="role">
<sng:value/>
</sng:attribute>
</sng:optional>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
	
<xsl:template match="sm:meta[@usage='optional']">
<sng:optional>
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</sng:optional>
</xsl:template>
<xsl:template match="sm:meta">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:template>
	
<xsl:template match="node()"/>
</xsl:stylesheet>