<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sng="http://relaxng.org/ns/structure/1.0"
		xmlns:snga="http://relaxng.org/ns/compatibility/annotations/1.0"
		xmlns:sm="http://www.utc.fr/ics/scenari/v3/modeling"
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
		xmlns:xalan="http://xml.apache.org/xalan"
		xmlns:sma="kelis.fr:scenari/modeling/assessment"
		exclude-result-prefixes="sc sp sm sng snga xalan sma"
		version="1.0">
<xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>
	
<xsl:include href="bsco:sm/model/relaxNg.xsl"/>	
	
<xsl:template match="sm:meta[@usage='optional']|sm:metaIfExternalized[@usage='optional']" mode="title">
<sng:optional>
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</sng:optional>
</xsl:template>
<xsl:template match="sm:meta|sm:metaIfExternalized" mode="title">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:template>
	
<xsl:template match="sm:allowedModel">
<xsl:if test="resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true'">
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</xsl:if>
</xsl:template>
	
<xsl:template match="sm:questionModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:question</xsl:with-param>
</xsl:call-template>
</xsl:template>
<xsl:template match="sm:globalExplanationModel">
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pEltName">sc:globalExplanation</xsl:with-param>
</xsl:call-template>
</xsl:template>
	
<xsl:template match="sm:scoreBounds">
<sng:element name="sc:score" snga:title="{filterInlineLoc(@name)}">
<xsl:if test="sm:pointsIfAllIsRight">
<sng:attribute name="max" snga:title="{filterInlineLoc(sm:pointsIfAllIsRight/@name)}"><sng:data type="int"/></sng:attribute>
</xsl:if>
<xsl:if test="sm:pointsIfAllIsWrong">
<sng:attribute name="min" snga:title="{filterInlineLoc(sm:pointsIfAllIsWrong)}"><sng:data type="int"/></sng:attribute>
</xsl:if>
<sng:empty/>
</sng:element>
</xsl:template>
<xsl:template match="sm:hintModel">
<sng:zeroOrMore>
<xsl:call-template name="tGetEltDeclaration">
<xsl:with-param name="pAttList">
<xsl:if test="sm:hintCost">
<sng:optional>
<sng:attribute name="cost">
<sng:data type="int"/>
</sng:attribute>
</sng:optional>
</xsl:if>
</xsl:with-param>
<xsl:with-param name="pEltName">sc:hint</xsl:with-param>
</xsl:call-template>
</sng:zeroOrMore>
</xsl:template>
	
	
<xsl:template name="tGetEltDeclaration">
<xsl:param name="pEltName"/>
<xsl:param name="pDocName" select="@name"/>
<xsl:param name="pAttList"/>
<xsl:variable name="vIsNotEmpty"><xsl:call-template name="isEltNotEmpty"/></xsl:variable>
<xsl:choose>
<xsl:when test="$vIsNotEmpty != ''">
<xsl:choose>
<xsl:when test="@usage='optional'">
<sng:optional>
<sng:element name="{$pEltName}">
<xsl:if test="$pDocName"><xsl:attribute name="snga:title"><xsl:value-of select="filterInlineLoc($pDocName)"/></xsl:attribute></xsl:if>
<xsl:copy-of select="$pAttList"/>
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</sng:element>
</sng:optional>
</xsl:when>
<xsl:otherwise>
<sng:element name="{$pEltName}">
<xsl:if test="$pDocName"><xsl:attribute name="snga:title"><xsl:value-of select="filterInlineLoc($pDocName)"/></xsl:attribute></xsl:if>
<xsl:copy-of select="$pAttList"/>
<sng:ref name="{resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/codeModel'))}"/>
</sng:element>
</xsl:otherwise>
</xsl:choose>
</xsl:when>
<xsl:otherwise><sng:empty/></xsl:otherwise>
</xsl:choose>
		
</xsl:template>
	
	
<xsl:template name="isEltNotEmpty">
<xsl:variable name="vIsInternalizable" select="si(resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true', true(), false())"/>
<xsl:if test="string-length((normalize-space(@sc:refUri)))=0 or $vIsInternalizable">1</xsl:if>
</xsl:template>
	
	
<xsl:template name="isAmEltNotEmpty">
<xsl:variable name="vIsInternalizable" select="si(@internalized = 'never', false(), testExpr(sm:allowedModel, resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isInternalizable')) = 'true', 'or'))"/>
<xsl:variable name="vIsExternalizable" select="si(@internalized = 'always', false(), testExpr(sm:allowedModel, resultatAgent(concat('@', getIdFromPath(@sc:refUri), '/isStandAloneItem')) = 'true', 'or'))"/>
<xsl:if test="count(sm:allowedModel)=0 or $vIsInternalizable or $vIsExternalizable">1</xsl:if>
</xsl:template>
	
<xsl:template match="*"/>
<xsl:template match="text()|@*"/>
</xsl:stylesheet>